#!/bin/bash
# SARG - Daily/Weekly/Monthly Squid usage report generation tool
# Thanks to Jeremy Lahners <jlahners@schemmer.com> and
# Leuchter Lars <LLeuchter@ea.com> for Daily/Weekly/Monthly bash code idea

# Written by Ugo Viti <u.viti@i-synapse.it>
VER=20030620


## HISTORY:
# 20030620 - Main Index Generation
# 20030619 - Solved 'sort' bug on Red Hat 9 systems
# 20030618 - First Version


## TODO:
# - More intelligent Weekly recognition
#   Like "begin of last week to end of last week",
#   doesn't like this script do: "7 days ago to yesterday"
# - Monthly recognition isn't so elegant
# - Suggestions are welcome :-)


######################################################################
## Configuration Parameters

# In your /etc/crontab insert the following lines:
# (the today report depend mostly of your squid server load average, tune it):

# 00 08-18/1 * * * root /usr/local/sbin/sarg.reports today
# 00 00 * * * root /usr/local/sbin/sarg.reports daily
# 00 01 * * 1 root /usr/local/sbin/sarg.reports weekly 
# 30 02 1 * * root /usr/local/sbin/sarg.reports monthly


# Customize the following variables:
# (Please, configure accurately the sarg.conf file)

       SARG=./sarg
     CONFIG=/usr/local/sarg/sarg.conf
    HTMLOUT=/var/www/html/i-synapse.it/admin/log/proxy

# Logo on Main Page, Language Translations and Exclude text from log Options (this text will be never logged)
  PAGETITLE="Statistiche Proxy Squid di $(hostname)"
    LOGOIMG=/images/logo-synapse.jpg
   LOGOLINK=http://www.i-synapse.it
      DAILY=Giornaliero
     WEEKLY=Settimanale
    MONTHLY=Mensile
EXCLUDELOG1="SARG: Nessun records trovato."
EXCLUDELOG2="SARG: Fine"


######################################################################
## Don't touch anything bellow

# Main index.html generation
echo -e "\
<html>\n\
<head>\n\
<title>$PAGETITLE</title>\n\
</head>\n\
<body>\n\
<div align=center>\n\
  <a href=$LOGOLINK><img border=0 src=$LOGOIMG></a>\n\
  <table border=0 cellspacing=6 cellpadding=7>\n\
    <tr>\n\
      <th align=center nowrap><b><font face=Arial size=4 color=green>$PAGETITLE</font></b></th>\n\
    </tr>\n\
    <tr>\n\
      <td align=center bgcolor=beige><font face=Arial size=3><a href=$DAILY>$DAILY</a></font></td>\n\
    </tr>\n\
    <tr>\n\
      <td align=center bgcolor=beige><font face=Arial size=3><a href=$WEEKLY>$WEEKLY</a></font></td>\n\
    </tr>\n\
    <tr>\n\
      <td align=center bgcolor=beige><font face=Arial size=3><a href=$MONTHLY>$MONTHLY</a></font></td>\n\
    </tr>\n\
  </table>\n\
</div>\n\
</body>\n\
</html>" > $HTMLOUT/index.html

# Errors Output Management
ERRORS=/tmp/sarg.reports.$RANDOM

# Date Calc
    TODAY=$(date --date "today" +%d/%m/%Y)
YESTERDAY=$(date --date "1 day ago" +%d/%m/%Y)
  WEEKAGO=$(date --date "1 week ago" +%d/%m/%Y)
 MONTHAGO=$(date --date "1 month ago" +01/%m/%Y)-$(date --date "1 month ago" +31/%m/%Y)

# Fix for Red Hat 9 systems and coreutils prior to 5.0 version
export LC_ALL=C

# Functions
exclude_from_log ()
{
  cat $ERRORS | grep -v "$EXCLUDELOG1" | grep -v "$EXCLUDELOG2"
  rm -f $ERRORS
}

today ()
{
  DAILYOUT=$HTMLOUT/$DAILY
  mkdir -p $DAILYOUT
  $SARG -f $CONFIG -d $TODAY -o $DAILYOUT >$ERRORS 2>&1
  exclude_from_log
}

daily ()
{
  DAILYOUT=$HTMLOUT/$DAILY
  mkdir -p $DAILYOUT
  $SARG -f $CONFIG -d $YESTERDAY -o $DAILYOUT >$ERRORS 2>&1
  exclude_from_log
}

weekly ()
{
  WEEKLYOUT=$HTMLOUT/$WEEKLY
  mkdir -p $WEEKLYOUT
  $SARG -f $CONFIG -d $WEEKAGO-$YESTERDAY -o $WEEKLYOUT >$ERRORS 2>&1
  exclude_from_log
}

monthly ()
{
  MONTHLYOUT=$HTMLOUT/$MONTHLY
  mkdir -p $MONTHLYOUT
  $SARG -f $CONFIG -d $MONTHAGO -o $MONTHLYOUT >$ERRORS 2>&1
  exclude_from_log
}

case $1 in
    today)
        today
        ;;
    daily)
        daily
        ;;
    weekly)
        weekly
        ;;
    monthly)
        monthly
        ;;
     *)
        echo "SARG - Daily/Weekly/Monthly Squid usage report generation tool"
        echo "Written by Ugo Viti <u.viti@i-synapse.it>"
        echo "Version: $VER"
        echo
        echo "Usage: $0 [OPTIONS]"
        echo
        echo "Allowed options:"
        echo "     today,  Generate a Today based report"
        echo "     daily,  Generate a Daily based report"
        echo "    weekly,  Generate a Weekly based report"
        echo "    montly,  Generate a Monthly based report"
        exit 0
esac